pynrc.simul.apt.AptInput
========================

.. currentmodule:: pynrc.simul.apt

.. autoclass:: AptInput
   :members:
   :inherited-members:
   :show-inheritance:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~AptInput.__init__
      ~AptInput.add_epochs
      ~AptInput.add_observation_info
      ~AptInput.add_options
      ~AptInput.base36encode
      ~AptInput.check_aperture_override
      ~AptInput.combine_dicts
      ~AptInput.create_input_table
      ~AptInput.expand_for_detectors
      ~AptInput.extract_grism_aperture
      ~AptInput.extract_value
      ~AptInput.full_path
      ~AptInput.get_pointing_info
      ~AptInput.global_alignment_pointing
      ~AptInput.tight_dithers
   
   

   
   
   